@@ -1,15 +1,16 @@
 # Message class. This is the type of object that is passed between components in the flow.
+import logging
 import re
 import base64
 import json
 import yaml
 import pprint
 
-from .log import log
 from .trace_message import TraceMessage
 from .utils import set_data_value, get_data_value
 from ..common import Message_NACK_Outcome
 
+log = logging.getLogger(__name__)
 
 class Message:
 
@@ -138,7 +139,7 @@ class Message:
 
         raise ValueError(
             f"Unknown data type '{data_type}' in expression '{expression}'"
-        ) from None
+        )
 
     def set_data_object(self, expression, value):
         data_type = expression.split(":")[0]
@@ -159,7 +160,7 @@ class Message:
         else:
             raise ValueError(
                 f"Unknown data type '{data_type}' in expression '{expression}'"
-            ) from None
+            )
 
     def set_iteration_data(self, item, index):
         self.iteration_data["item"] = item
@@ -231,7 +232,7 @@ class Message:
         else:
             raise ValueError(
                 f"Unknown encoding '{encoding}' in expression '{encoding_expression}'"
-            ) from None
+            )
 
         return data
 
