@@ -1,6 +1,7 @@
 """This is a simple broker for testing purposes. It allows sending and receiving
 messages to/from queues. It supports subscriptions based on topics."""
 
+import logging
 from typing import Dict, List, Any
 import queue
 import re
@@ -9,8 +10,8 @@ from enum import Enum
 
 from .messaging import Messaging
 from ...common import Message_NACK_Outcome
-from ..log import log
 
+log = logging.getLogger(__name__)
 
 class DevConnectionStatus(Enum):
     CONNECTED = "CONNECTED"
@@ -73,7 +74,7 @@ class DevBroker(Messaging):
 
     def receive_message(self, timeout_ms, queue_name: str):
         if not self.connected:
-            raise RuntimeError("DevBroker is not connected") from None
+            raise RuntimeError("DevBroker is not connected")
 
         try:
             return self.queues[queue_name].get(timeout=timeout_ms / 1000)
@@ -88,7 +89,7 @@ class DevBroker(Messaging):
         user_context: Dict = None,
     ):
         if not self.connected:
-            raise RuntimeError("DevBroker is not connected") from None
+            raise RuntimeError("DevBroker is not connected")
 
         message = {
             "payload": payload,
@@ -107,7 +108,7 @@ class DevBroker(Messaging):
 
     def subscribe(self, subscription: str, queue_name: str):
         if not self.connected:
-            raise RuntimeError("DevBroker is not connected") from None
+            raise RuntimeError("DevBroker is not connected")
 
         subscription = self._subscription_to_regex(subscription)
 
