@@ -7,13 +7,13 @@ class Messaging:
         self.broker_properties = broker_properties
 
     def connect(self):
-        raise NotImplementedError from None
+        raise NotImplementedError
 
     def disconnect(self):
-        raise NotImplementedError from None
+        raise NotImplementedError
 
     def receive_message(self, timeout_ms, queue_id: str):
-        raise NotImplementedError from None
+        raise NotImplementedError
 
     def send_message(
         self,
@@ -22,4 +22,4 @@ class Messaging:
         user_properties: Dict = None,
         user_context: Dict = None,
     ):
-        raise NotImplementedError from None
+        raise NotImplementedError
