@@ -43,4 +43,4 @@ class MessagingServiceBuilder:
 
         raise ValueError(
             f"Unsupported broker type: {self.broker_properties['broker_type']}. Please either enable dev_mode or use a supported broker type."
-        ) from None
+        )
