@@ -34,9 +34,9 @@ from solace.messaging.errors.pubsubplus_client_error import PubSubPlusClientErro
 from solace import SOLACE_LOGGING_CONFIG
 
 from .messaging import Messaging
-from ..log import log
 from ...common import Message_NACK_Outcome
 
+log = logging.getLogger(__name__)
 
 class ConnectionStatus(Enum):
     RECONNECTING = 2
@@ -107,10 +107,9 @@ class ServiceEventHandler(
 
         try:
             self.strategy = ConnectionStrategy(strategy)
-        except ValueError as e:
-            log.error(
+        except ValueError:
+            log.exception(
                 f"{self.error_prefix} Invalid reconnection strategy: {strategy}. Using default strategy.",
-                trace=e,
             )
             self.strategy = ConnectionStrategy.FOREVER_RETRY
 
@@ -301,7 +300,7 @@ class SolaceMessaging(Messaging):
                         else:
                             temp_retry_count -= 1
 
-                    log.info(f"{self.error_prefix} Connecting to broker...")
+                    log.info(f"{self.error_prefix} Connecting to broker at {self.broker_properties.get('host')} ...")
                     self.stop_signal.wait(timeout=retry_interval / 1000)
 
             log_thread = threading.Thread(target=log_connecting, daemon=True)
@@ -317,7 +316,7 @@ class SolaceMessaging(Messaging):
             if self.stop_signal.is_set():
                 log.error(f"{self.error_prefix} Stopping connection attempt")
                 self.disconnect()
-                raise KeyboardInterrupt("Stopping connection attempt") from None
+                raise KeyboardInterrupt("Stopping connection attempt")
 
             self.stop_connection_log.set()
             log.info(f"{self.error_prefix} Successfully connected to broker.")
@@ -365,10 +364,10 @@ class SolaceMessaging(Messaging):
                     self.broker_properties.get("max_redelivery_count"),
                     self.broker_properties.get("create_queue_on_start"),
                 )
-        except KeyboardInterrupt:  # pylint: disable=broad-except
-            raise KeyboardInterrupt from None
+        except KeyboardInterrupt:
+            raise
         except Exception as e:
-            raise ValueError("Error in broker connection") from None
+            raise ValueError("Error in broker connection") from e
 
     def bind_to_queue(
         self,
@@ -420,9 +419,8 @@ class SolaceMessaging(Messaging):
                         **end_point_props,
                     }
                 except Exception as e:
-                    log.error(
-                        f"{self.error_prefix} Error setting max redelivery count",
-                        trace=e,
+                    log.exception(
+                        f"{self.error_prefix} Error setting max redelivery count"
                     )
 
             self.persistent_receiver.start()
@@ -436,10 +434,9 @@ class SolaceMessaging(Messaging):
         # Handle API exception
         except PubSubPlusClientError:
             log.warning(
-                f"{self.error_prefix} Error creating persistent receiver for queue [%s]",
-                queue_name,
+                f"{self.error_prefix} Error creating persistent receiver for queue [{queue_name}]"
             )
-            raise exception
+            raise
 
         # Add to list of receivers
         self.persistent_receivers.append(self.persistent_receiver)
@@ -459,8 +456,8 @@ class SolaceMessaging(Messaging):
             change_connection_status(
                 self.connection_properties, ConnectionStatus.DISCONNECTED
             )
-        except Exception as e:  # pylint: disable=broad-except
-            log.error(f"{self.error_prefix} Error disconnecting", trace=e)
+        except Exception:  # pylint: disable=broad-except
+            log.exception(f"{self.error_prefix} Error disconnecting")
 
     def get_connection_status(self):
         return self.connection_properties["status"]
@@ -532,17 +529,14 @@ class SolaceMessaging(Messaging):
                 f"{self.error_prefix} Successfully added subscription '{topic_str}' to receiver."
             )
             return True
-        except PubSubPlusClientError as e:
-            log.error(
-                f"{self.error_prefix} Error adding subscription '{topic_str}'.",
-                trace=e,
+        except PubSubPlusClientError:
+            log.exception(
+                f"{self.error_prefix} Error adding subscription '{topic_str}'."
             )
             return False
-        except Exception as e:
-            log.error(
-                f"{self.error_prefix} Unexpected error adding subscription '{topic_str}'.",
-                exc_info=True,
-                trace=e,
+        except Exception:
+            log.exception(
+                f"{self.error_prefix} Unexpected error adding subscription '{topic_str}'."
             )
             return False
 
@@ -567,17 +561,14 @@ class SolaceMessaging(Messaging):
                 f"{self.error_prefix} Successfully removed subscription '{topic_str}' from receiver."
             )
             return True
-        except PubSubPlusClientError as e:
-            log.error(
-                f"{self.error_prefix} Error removing subscription '{topic_str}'.",
-                trace=e,
+        except PubSubPlusClientError:
+            log.exception(
+                f"{self.error_prefix} Error removing subscription '{topic_str}'."
             )
             return False
-        except Exception as e:
-            log.error(
-                f"{self.error_prefix} Unexpected error removing subscription '{topic_str}'.",
-                exc_info=True,
-                trace=e,
+        except Exception:
+            log.exception(
+                f"{self.error_prefix} Unexpected error removing subscription '{topic_str}'."
             )
             return False
 
