@@ -1,9 +1,9 @@
 """Assembly component for the Solace AI Event Connector"""
-
-from ...common.log import log
+import logging
 from ..component_base import ComponentBase
 from ...common.message import Message
 
+log = logging.getLogger(__name__)
 
 info = {
     "class_name": "Assembly",
@@ -73,7 +73,7 @@ class Assembly(ComponentBase):
             log.error("Message does not have the assemble key or it is not a string")
             raise ValueError(
                 f"Message does not have the key {self.assemble_key} or it is not a string"
-            ) from None
+            )
 
         event_key = data[self.assemble_key]
         # Fetch the current assembly from cache
