@@ -1,11 +1,10 @@
 """MongoDB database handler for MongoDB agent."""
-
+import logging
 from pymongo import MongoClient
 from typing import List, Dict, Any, Tuple
 import threading
 
-from .....common.log import log
-
+log = logging.getLogger(__name__)
 
 class MongoHandler:
     """Handler for MongoDB database operations."""
@@ -43,8 +42,8 @@ class MongoHandler:
                 self.local.client = MongoClient(connection_string)
                 self.local.db = self.local.client[self.database_name]
                 log.info("Successfully connected to MongoDB database")
-            except Exception as e:
-                log.error("Error connecting to MongoDB database", trace=e)
+            except Exception:
+                log.exception("Error connecting to MongoDB database")
                 raise ValueError("Failed to connect to MongoDB database") from None
         return self.local.db
 
@@ -62,14 +61,14 @@ class MongoHandler:
             log.error("Documents must be a dictionary or list of dictionaries")
             raise ValueError(
                 "Documents must be a dictionary or list of dictionaries"
-            ) from None
+            )
         if isinstance(documents, dict):
             documents = [documents]
         if not documents or not isinstance(documents[0], dict):
             log.error("Documents must be a dictionary or list of dictionaries")
             raise ValueError(
                 "Documents must be a dictionary or list of dictionaries"
-            ) from None
+            )
         db = self.get_connection()
         result = db[collection].insert_many(documents)
         log.debug(
@@ -96,7 +95,7 @@ class MongoHandler:
             ValueError: If pipeline is not a valid aggregation pipeline.
         """
         if not isinstance(pipeline, list):
-            raise ValueError("Pipeline must be a list of aggregation stages") from None
+            raise ValueError("Pipeline must be a list of aggregation stages")
 
         # Validate each pipeline stage
         for stage in pipeline:
@@ -104,14 +103,14 @@ class MongoHandler:
                 log.error("Each pipeline stage must be a non-empty dictionary")
                 raise ValueError(
                     "Each pipeline stage must be a non-empty dictionary"
-                ) from None
+                )
             if not any(key.startswith("$") for key in stage.keys()):
                 log.error(
                     "Invalid pipeline stage: %s. Each stage must start with '$'", stage
                 )
                 raise ValueError(
                     f"Invalid pipeline stage: {stage}. Each stage must start with '$'"
-                ) from None
+                )
 
         try:
             db = self.get_connection()
@@ -125,8 +124,8 @@ class MongoHandler:
             result = list(cursor)
             result = self._remove_object_ids(result)
             return result
-        except Exception as e:
-            log.error("Error executing MongoDB query", trace=e)
+        except Exception:
+            log.exception("Error executing MongoDB query")
             raise ValueError("Failed to execute MongoDB query") from None
 
     def get_collections(self) -> List[str]:
