@@ -1,9 +1,10 @@
 """MongoDB Agent Component for handling database insert."""
-
+import logging
 import datetime
 import dateutil.parser
 from .mongo_base import MongoDBBaseComponent, info as base_info
-from .....common.log import log
+
+log = logging.getLogger(__name__)
 
 info = base_info.copy()
 info["class_name"] = "MongoDBInsertComponent"
@@ -40,27 +41,19 @@ class MongoDBInsertComponent(MongoDBBaseComponent):
         self.data_types_map = self.get_config("data_types")
         if self.data_types_map:
             if not isinstance(self.data_types_map, dict):
-                log.error(
-                    "Invalid data types provided for MongoDB insert. Expected a dictionary. Provided: %s",
-                    self.data_types_map,
-                )
                 raise ValueError(
-                    "Invalid data types provided for MongoDB insert. Expected a dictionary."
-                ) from None
+                    f"Invalid data types provided for MongoDB insert. Expected a dictionary. Provided: {self.data_types_map}"
+                )
             for key, field_type in self.data_types_map.items():
                 if (
                     not isinstance(key, str)
                     or not isinstance(field_type, str)
                     or field_type.lower() not in POSSIBLE_TYPES
                 ):
-                    log.error(
-                        "Invalid data types provided for MongoDB insert. Expected a dictionary with key value pairs where key is a string and value is a string from the following list: %s",
-                        POSSIBLE_TYPES,
-                    )
                     raise ValueError(
                         "Invalid data types provided for MongoDB insert. Expected a dictionary with key value pairs where key is a string and value is a string from the following list: "
                         + ", ".join(POSSIBLE_TYPES)
-                    ) from None
+                    )
 
     def invoke(self, message, data):
         if not data or not isinstance(data, dict) and not isinstance(data, list):
@@ -69,7 +62,7 @@ class MongoDBInsertComponent(MongoDBBaseComponent):
             )
             raise ValueError(
                 "Invalid data provided for MongoDB insert. Expected a dictionary or a list of dictionary."
-            ) from None
+            )
 
         if self.data_types_map:
             for key, field_type in self.data_types_map.items():
@@ -131,8 +124,7 @@ class MongoDBInsertComponent(MongoDBBaseComponent):
                         return parsed_date
                     except Exception as cleanup_error:
                         log.error(
-                            "[mongo_insert] Failed to parse even after cleanup.",
-                            trace=f"Original: '{value}', Cleaned: '{cleaned_value}', Cleanup Error: {cleanup_error}",
+                            f"[mongo_insert] Failed to parse even after cleanup. Original: '{value}', Cleaned: '{cleaned_value}', Cleanup Error: {cleanup_error}",
                         )
                         # Provide helpful error message with suggestions
                         error_msg = (
