@@ -1,6 +1,8 @@
 # This component splits a long text into smaller parts using the LangChain text splitter module
 
-from .....common.log import log
+import logging
+
+log = logging.getLogger(__name__)
 
 from .langchain_base import (
     LangChainBase,
@@ -79,8 +81,8 @@ class LangChainTextSplitter(LangChainBase):
         try:
             chunks = self.component.split_text(data)
             return chunks
-        except Exception as e:
-            log.error("Error splitting text", trace=e)
+        except Exception:
+            log.exception("Error splitting text")
             return []
 
 
@@ -105,6 +107,6 @@ class SingleChunkSplitter:
         """
         try:
             return [data]
-        except Exception as e:
-            log.error("Error wrapping data", trace=e)
+        except Exception:
+            log.exception("Error wrapping data")
             return []
