@@ -3,7 +3,9 @@
 # as well, so the configuration for this component will also include the
 # embedding model configuration
 
-from .....common.log import log
+import logging
+log = logging.getLogger(__name__)
+
 from .langchain_vector_store_embedding_base import (
     LangChainVectorStoreEmbeddingsBase,
 )
@@ -114,17 +116,17 @@ class LangChainVectorStoreDelete(LangChainVectorStoreEmbeddingsBase):
             if expr is None:
                 raise ValueError(
                     "In LangChainVectorStoreDelete, expr not provided in delete_kwargs"
-                ) from None
+                )
             try:
                 delete_ids = self.vector_store.get_pks(expr)
-            except Exception:  # pylint: disable=broad-except
-                log.warning("%sFailed to get pks from Milvus.", self.log_identifier)
+            except Exception as e:  # pylint: disable=broad-except
+                log.warning(f"{self.log_identifier} Failed to get pks from Milvus: {e}")
                 delete_ids = []
             del delete_kwargs["expr"]
 
         try:
             result = self.vector_store.delete(delete_ids, **delete_kwargs)
-        except Exception:  # pylint: disable=broad-except
-            log.warning("%sFailed to delete from vector store.", self.log_identifier)
+        except Exception as e:  # pylint: disable=broad-except
+            log.warning(f"{self.log_identifier} Failed to delete from vector store: {e}")
             result = False
         return {"result": result}
