@@ -4,7 +4,9 @@ as well, so the configuration for this component will also include the
 embedding model configuration
 """
 
-from .....common.log import log
+import logging
+log = logging.getLogger(__name__)
+
 from .langchain_vector_store_embedding_base import (
     LangChainVectorStoreEmbeddingsBase,
 )
@@ -100,8 +102,8 @@ class LangChainVectorStoreEmbeddingsSearch(LangChainVectorStoreEmbeddingsBase):
         )
         try:
             result = self.vector_store.similarity_search(text, k=k)
-        except Exception as e:
-            log.error("Error while searching in the vector store", trace=e)
+        except Exception:
+            log.exception("Error while searching in the vector store")
             raise ValueError("Error while searching in the vector store.") from None
         log.debug("Searched and got result")
         # Clean up the result by looping through all the Documents and extracting the metadata and page_content
