@@ -1,5 +1,6 @@
 """Base class for LiteLLM chat models"""
 
+import logging
 import litellm
 import time
 
@@ -10,10 +11,11 @@ from litellm.router import RetryPolicy
 from litellm.router import AllowedFailsPolicy
 
 from ....component_base import ComponentBase
-from .....common.log import log
 from .....common import Message_NACK_Outcome
 from .....common.monitoring import Metrics
 
+log = logging.getLogger(__name__)
+
 litellm_info_base = {
     "class_name": "LiteLLMChatModelBase",
     "description": "Base class for LiteLLM chat models",
@@ -75,6 +77,26 @@ litellm_info_base = {
             "description": "Request timeout in seconds",
             "default": 60,
         },
+        {
+            "name": "suppress_debug_info",
+            "required": False,
+            "description": "Whether to suppress debug info in LiteLLM",
+            "default": False,
+            "type": "boolean",
+        },
+        {
+            "name": "aiohttp_trust_env",
+            "required": False,
+            "description": "Whether to trust environment variables for aiohttp",
+            "default": True,
+            "type": "boolean",
+        },
+        {
+            "name": "ssl_verify",
+            "required": False,
+            "description": "Whether to verify SSL certificates. Can be a boolean or a path to a PEM file.",
+            "default": False,
+        },
         {
             "name": "retry_policy",
             "required": False,
@@ -103,7 +125,22 @@ class LiteLLMBase(ComponentBase):
         self.init_load_balancer()
 
     def init(self):
-        litellm.suppress_debug_info = True
+        # Get configuration parameters
+        suppress_debug_info = self.get_config("suppress_debug_info", False)
+        aiohttp_trust_env = self.get_config("aiohttp_trust_env", True)
+        ssl_verify = self.get_config("ssl_verify", False)
+
+        # Set LiteLLM parameters
+        litellm.suppress_debug_info = suppress_debug_info
+        litellm.aiohttp_trust_env = aiohttp_trust_env
+        litellm.ssl_verify = ssl_verify
+        
+        # Turn on debug if suppress_debug_info is True
+        if suppress_debug_info:
+            litellm._turn_on_debug()
+            
+        log.info(f"LiteLLM initialized with suppress_debug_info={suppress_debug_info}, aiohttp_trust_env={aiohttp_trust_env}, ssl_verify={ssl_verify}")
+        
         self.timeout = self.get_config("timeout")
         self.retry_policy_config = self.get_config("retry_policy")
         self.allowed_fails_policy_config = self.get_config("allowed_fails_policy")
@@ -181,8 +218,8 @@ class LiteLLMBase(ComponentBase):
                 timeout=self.timeout,
             )
             log.debug("Litellm Load balancer was initialized")
-        except Exception:
-            raise ValueError("Error initializing load balancer") from None
+        except Exception as e:
+            raise ValueError("Error initializing load balancer") from e
 
     def load_balance(self, messages, stream):
         """load balance the messages"""
@@ -195,16 +232,15 @@ class LiteLLMBase(ComponentBase):
                 stream=stream,
                 **({"stream_options": {"include_usage": True}} if stream else {}),
             )
-        except litellm.BadRequestError as e:
-            # Handle context window exceeded error
-            if "ContextWindowExceededError" in str(e):
-                log.error("Context window exceeded error", trace=e)
-                return self.context_exceeded_response(model)
-            log.error("Bad request error.", trace=e)
-            raise ValueError("Error LiteLLM bad request") from None
-        except Exception as e:
-            log.error("LiteLLM API connection error.", trace=e)
-            raise ValueError("Error LiteLLM API connection") from None
+        except litellm.ContextWindowExceededError:
+            log.exception("Context window exceeded error")
+            return self.context_exceeded_response(model)
+        except litellm.BadRequestError:
+            log.exception("Error LiteLLM bad request")
+            raise
+        except Exception:
+            log.exception("LiteLLM API connection error.")
+            raise
 
         log.debug("Load balancer responded")
         return response
