@@ -1,5 +1,6 @@
 """LiteLLM chat model component"""
 
+import logging
 import uuid
 import time
 from litellm import cost_per_token
@@ -7,9 +8,10 @@ from litellm import APIConnectionError
 from .litellm_base import LiteLLMBase
 from .litellm_base import litellm_info_base
 from .....common.message import Message
-from .....common.log import log
 from .....common.monitoring import Metrics
 
+log = logging.getLogger(__name__)
+
 litellm_chat_info_base = litellm_info_base.copy()
 litellm_chat_info_base.update(
     {
@@ -122,8 +124,8 @@ class LiteLLMChatModelBase(LiteLLMBase):
 
         if self.stream_to_flow and self.stream_to_next_component:
             raise ValueError(
-                "stream_to_flow and stream_to_next_component are mutually exclusive"
-            ) from None
+                "stream_to_flow and stream_to_next_component are mutually exclusive. Please set only one of these options"
+            )
 
     def invoke(self, message, data):
         """invoke the model"""
@@ -158,11 +160,11 @@ class LiteLLMChatModelBase(LiteLLMBase):
             return {"content": response.choices[0].message.content}
         except APIConnectionError as e:
             error_str = str(e)
-            log.error("Error invoking LiteLLM", trace=e)
+            log.exception("Error invoking LiteLLM")
             return {"content": error_str, "handle_error": True}
-        except Exception as e:
-            log.error("Error invoking LiteLLM", trace=e)
-            raise ValueError("Error invoking LiteLLM") from None
+        except Exception:
+            log.exception("Error invoking LiteLLM")
+            raise
 
     def invoke_stream(self, message, messages):
         """invoke the model with streaming"""
@@ -222,15 +224,15 @@ class LiteLLMChatModelBase(LiteLLMBase):
 
         except APIConnectionError as e:
             error_str = str(e)
-            log.error("Error invoking LiteLLM", trace=e)
+            log.exception("Error invoking LiteLLM")
             return {
                 "content": error_str,
                 "response_uuid": response_uuid,
                 "handle_error": True,
             }
-        except Exception as e:
-            log.error("Error invoking LiteLLM", trace=e)
-            raise ValueError("Error invoking LiteLLM") from None
+        except Exception:
+            log.exception("Error invoking LiteLLM")
+            raise
 
         if self.stream_to_next_component:
             # Just return the last chunk
