@@ -1,10 +1,12 @@
 """LiteLLM chat model component with conversation history"""
 
+import logging
 import time
 
 from .litellm_chat_model_base import LiteLLMChatModelBase, litellm_chat_info_base
 from ..common.chat_history_handler import ChatHistoryHandler
-from .....common.log import log
+
+log = logging.getLogger(__name__)
 
 info = litellm_chat_info_base.copy()
 info["class_name"] = "LiteLLMChatModelWithHistory"
@@ -47,15 +49,15 @@ class LiteLLMChatModelWithHistory(LiteLLMChatModelBase, ChatHistoryHandler):
     def invoke(self, message, data):
         session_id = data.get("session_id")
         if not session_id:
-            raise ValueError("session_id is not provided") from None
+            raise ValueError("session_id is not provided")
 
         clear_history_but_keep_depth = data.get("clear_history_but_keep_depth")
         try:
             if clear_history_but_keep_depth is not None:
                 clear_history_but_keep_depth = max(0, int(clear_history_but_keep_depth))
-        except (TypeError, ValueError) as e:
-            log.error(
-                "Invalid clear_history_but_keep_depth value. Defaulting to 0.", trace=e
+        except (TypeError, ValueError):
+            log.exception(
+                "Invalid clear_history_but_keep_depth value. Defaulting to 0."
             )
             clear_history_but_keep_depth = 0
         messages = data.get("messages", [])
