@@ -1,12 +1,13 @@
 """Base class for OpenAI chat models"""
 
+import logging
 import uuid
-import time
 
 from openai import OpenAI
 from ....component_base import ComponentBase
 from .....common.message import Message
-from .....common.log import log
+
+log = logging.getLogger(__name__)
 
 openai_info_base = {
     "class_name": "OpenAIChatModelBase",
@@ -157,7 +158,7 @@ class OpenAIChatModelBase(ComponentBase):
         if self.stream_to_flow and self.stream_to_next_component:
             raise ValueError(
                 "stream_to_flow and stream_to_next_component are mutually exclusive"
-            ) from None
+            )
 
     def invoke(self, message, data):
         messages = data.get("messages", [])
@@ -179,11 +180,11 @@ class OpenAIChatModelBase(ComponentBase):
                         temperature=self.temperature,
                     )
                     return {"content": response.choices[0].message.content}
-                except Exception as e:
-                    log.error("Error invoking OpenAI", trace=e)
+                except Exception:
                     max_retries -= 1
+                    log.exception(f"Error invoking OpenAI. Will retry {max_retries} more times.")
                     if max_retries <= 0:
-                        raise ValueError("Max retries exceeded") from None
+                        raise
                     else:
                         self.stop_signal.wait(timeout=1)
 
@@ -232,11 +233,11 @@ class OpenAIChatModelBase(ComponentBase):
                                 )
                             current_batch = ""
                             first_chunk = False
-            except Exception as e:
-                log.error("Error invoking OpenAI", trace=e)
+            except Exception:
                 max_retries -= 1
+                log.exception(f"Error invoking OpenAI. Will retry {max_retries - 1} more times.")
                 if max_retries <= 0:
-                    raise ValueError("Max retries exceeded") from None
+                    raise
                 else:
                     # Small delay before retrying
                     self.stop_signal.wait(timeout=1)
