@@ -52,16 +52,16 @@ class Parser(ComponentBase):
         input_format = self.get_config("input_format")
         output_format = self.get_config("output_format")
         if not input_format or not output_format:
-            raise ValueError("Input and output format must be provided.") from None
+            raise ValueError("Input and output format must be provided.")
 
         dict_data = data  # By default assuming it's already a dictionary
         try:
             if input_format == "json" or input_format == "yaml":
                 dict_data = self.str_to_dict(data, input_format)
             elif input_format != "dict":
-                raise ValueError(f"Invalid input format: {input_format}") from None
-        except Exception:
-            raise ValueError("Error converting input") from None
+                raise ValueError(f"Invalid input format: {input_format}")
+        except Exception as e:
+            raise ValueError("Error converting input") from e
 
         try:
             if output_format == "json" or output_format == "yaml":
@@ -69,6 +69,6 @@ class Parser(ComponentBase):
             elif output_format == "dict":
                 return dict_data
             else:
-                raise ValueError(f"Invalid output format: {output_format}") from None
-        except Exception:
-            raise ValueError("Error converting output") from None
+                raise ValueError(f"Invalid output format: {output_format}")
+        except Exception as e:
+            raise ValueError("Error converting output") from e
