@@ -1,7 +1,10 @@
 """Scrape a website"""
 
+import logging
+
 from ...component_base import ComponentBase
-from ....common.log import log
+
+log = logging.getLogger(__name__)
 
 info = {
     "class_name": "WebScraper",
@@ -41,8 +44,8 @@ class WebScraper(ComponentBase):
 
     def invoke(self, message, data):
         url = data["url"]
-        if type(url) != str or not url:
-            raise ValueError("No URL provided") from None
+        if not isinstance(url, str) or not url:
+            raise ValueError("No URL provided")
         content = self.scrape(url)
         return content
 
@@ -50,9 +53,9 @@ class WebScraper(ComponentBase):
     def scrape(self, url):
         try:
             from playwright.sync_api import sync_playwright
-        except ImportError as e:
+        except ImportError:
             err_msg = "Please install playwright by running 'pip install playwright' and 'playwright install'."
-            log.error(err_msg, trace=e)
+            log.exception(err_msg)
             raise ValueError(err_msg) from None
 
         with sync_playwright() as p:
@@ -62,9 +65,9 @@ class WebScraper(ComponentBase):
                     headless=True,
                     timeout=self.timeout,
                 )  # Set headless=False to see the browser in action
-            except ImportError as e:
+            except ImportError:
                 err_msg = "Failed to launch the Chromium instance. Please install the browser binaries by running 'playwright install'"
-                log.error(err_msg, trace=e)
+                log.exception(err_msg)
                 raise ValueError(err_msg) from None
 
             resp = {}
@@ -89,8 +92,8 @@ class WebScraper(ComponentBase):
                 log.debug("Scraped the website.")
                 browser.close()
                 return resp
-            except Exception as e:
-                log.error("Failed to scrape the website.", trace=e)
+            except Exception:
+                log.exception("Failed to scrape the website.")
                 browser.close()
                 return {
                     "title": "",
