@@ -70,8 +70,8 @@ class WebSearchDuckDuckGo(WebSearchBase):
         self.url = "http://api.duckduckgo.com/"
 
     def invoke(self, message, data):
-        if type(data) != str or not data:
-            raise ValueError("Invalid search query") from None
+        if not isinstance(data, str) or not data:
+            raise ValueError("Invalid search query. Search query must be a non-empty string")
         params = {
             "q": data,  # User query
             "format": "json",  # Response format (json by default)
@@ -86,7 +86,7 @@ class WebSearchDuckDuckGo(WebSearchBase):
             response = self.parse(response)
             return response
         else:
-            raise ValueError(f"Error: {response.status_code}") from None
+            raise ValueError(f"Error: {response.status_code}")
 
     # Extract required data from a message
     def parse(self, message):
