@@ -1,13 +1,9 @@
 import time
 from copy import deepcopy
 
-
 from ..component_base import ComponentBase
 from ...common.message import Message
 
-# from ...common.log import log
-
-
 info = {
     "class_name": "TimerInput",
     "description": "An input that will generate a message at a specified interval.",
@@ -43,7 +39,7 @@ class TimerInput(ComponentBase):
         if not self.interval_ms:
             raise ValueError(
                 "interval_ms configuration parameter is required for timer_input component."
-            ) from None
+            )
         self.skip_messages_if_behind = self.get_config("skip_messages_if_behind")
         self.last_message_time = None
 
