@@ -1,16 +1,17 @@
 """This component receives messages from a websocket connection and sends them to the next component in the flow."""
 
+import logging
 import json
 import os
 import copy
 
 from flask import request
-from ...common.log import log
 from ...common.message import Message
 from ...common.event import Event, EventType
 from ...common.utils import decode_payload
 from .websocket_base import WebsocketBase, base_info
 
+log = logging.getLogger(__name__)
 
 # Merge base_info into info
 info = copy.deepcopy(base_info)
@@ -40,7 +41,7 @@ class WebsocketInput(WebsocketBase):
         self.payload_format = self.get_config("payload_format")
 
         if not self.listen_port:
-            raise ValueError("listen_port is required for WebsocketInput") from None
+            raise ValueError("listen_port is required for WebsocketInput")
 
         if not os.path.isabs(self.html_path):
             self.html_path = os.path.join(os.getcwd(), self.html_path)
@@ -60,15 +61,15 @@ class WebsocketInput(WebsocketBase):
                 )
                 event = Event(EventType.MESSAGE, message)
                 self.process_event_with_tracing(event)
-            except json.JSONDecodeError as e:
-                log.error("Received invalid payload.", trace=e)
-            except AssertionError as e:
-                log.error("Error in payload format.", trace=e)
+            except json.JSONDecodeError:
+                log.exception("Received invalid payload.")
+            except AssertionError:
+                log.exception("Error in payload format.")
                 raise AssertionError(
                     "Error Payload format. Please check the payload format."
                 ) from None
             except Exception as e:
-                log.error("Error processing WebSocket message.", trace=e)
+                log.exception("Error processing WebSocket message.")
                 self.handle_component_error(e, event)
 
     def run(self):
@@ -84,6 +85,6 @@ class WebsocketInput(WebsocketBase):
                 "topic": message.get_topic(),
                 "user_properties": message.get_user_properties(),
             }
-        except Exception as e:
-            log.error("Error processing WebSocket message.", trace=e)
+        except Exception:
+            log.exception("Error processing WebSocket message.")
             return None
