@@ -1,10 +1,12 @@
 """App class for the Solace AI Event Connector"""
 
+import logging
 from typing import List, Dict, Any, Optional
 from copy import deepcopy
 
-from ..common.log import log
 from .flow import Flow
+
+log = logging.getLogger(__name__)
 from ..common.utils import (
     deep_merge,
     resolve_config_values,
@@ -112,15 +114,12 @@ class App:
                     connector=self.connector,
                 )
                 # Store controller instance (already done by assignment above)
-            except Exception as e:
-                log.error(
-                    "Failed to initialize RequestResponseFlowController for app '%s'.",
-                    self.name,
-                    exc_info=True,
-                    trace=e,
+            except Exception:
+                log.exception(
+                    f"Failed to initialize RequestResponseFlowController for app '{self.name}'."
                 )
                 # Decide if this should be a fatal error for the app
-                raise e
+                raise
 
     def _validate_app_config(self):
         """Validates self.app_config against the class's app_schema."""
@@ -197,7 +196,7 @@ class App:
                 log.debug("Initializing simplified flow for app %s", self.name)
                 # Validate presence of broker and components if not a custom App subclass
                 # (Custom subclasses might define flows differently)
-                if type(self) == App:  # Only validate for the base App class
+                if isinstance(self, App):  # Only validate for the base App class
                     if (
                         "broker" not in self.app_info
                         or "components" not in self.app_info
@@ -205,7 +204,7 @@ class App:
                         raise ValueError(
                             f"Simplified app '{self.name}' must define 'broker' and 'components' keys "
                             "(or be a standard app with a 'flows' key)."
-                        ) from None
+                        )
                 # Call helper to generate implicit flow config
                 flow_config = self._create_simplified_flow_config()
                 # Create the single implicit flow
@@ -214,8 +213,8 @@ class App:
                 self.flow_input_queues[flow_config.get("name")] = flow_input_queue
                 self.flows.append(flow_instance)
 
-        except Exception as e:
-            log.error(f"Error initializing flows for app {self.name}", trace=e)
+        except Exception:
+            log.exception(f"Error initializing flows for app {self.name}")
             raise ValueError(
                 f"Error initializing flows for app '{self.name}'. Check the configuration."
             )
@@ -358,19 +357,17 @@ class App:
                 # If not, cleanup might involve stopping its internal flow/app
                 # For now, we rely on the connector cleaning up all apps/flows
                 pass  # RRC's internal app/flow will be cleaned by connector.cleanup()
-            except Exception as e:
-                log.error(
-                    "Error cleaning up RequestResponseFlowController in app %s",
-                    self.name,
-                    trace=e,
+            except Exception:
+                log.exception(
+                    f"Error cleaning up RequestResponseFlowController in app {self.name}"
                 )
             self.request_response_controller = None
 
         for flow in self.flows:
             try:
                 flow.cleanup()
-            except Exception as e:
-                log.error(f"Error cleaning up flow in app {self.name}", trace=e)
+            except Exception:
+                log.exception(f"Error cleaning up flow in app {self.name}")
         self.flows.clear()
         self.flow_input_queues.clear()
         self._broker_output_component = None  # Clear cache
@@ -464,12 +461,9 @@ class App:
                 topic,
             )
             self._broker_output_component.enqueue(event)
-        except Exception as e:
-            log.error(
-                "App '%s' failed to enqueue message to BrokerOutput.",
-                self.name,
-                trace=e,
-                exc_info=True,
+        except Exception:
+            log.exception(
+                f"App '{self.name}' failed to enqueue message to BrokerOutput."
             )
 
     @classmethod
