@@ -20,14 +20,17 @@ Each component can optionally create multiple of these using the configuration:
 
 """
 
+import logging
 import queue
 import time
+import threading
 from typing import Dict, Any
 
 from ..common.message import Message
 from ..common.event import Event, EventType
-from ..common.log import log
+from ..common.exceptions import SessionClosedError
 
+log = logging.getLogger(__name__)
 
 # This is a very basic component which will be stitched onto the final component in the flow
 class RequestResponseControllerOuputComponent:
@@ -52,6 +55,7 @@ class RequestResponseFlowController:
         self.response_queue = None
         self.enqueue_time = None
         self.request_outstanding = False
+        self._is_shutdown = threading.Event()
 
         # Create the flow configuration
         flow_config = self.create_broker_request_response_flow_config()
@@ -64,7 +68,7 @@ class RequestResponseFlowController:
         if not app.flows:
             raise ValueError(
                 "Failed to create internal broker request-response flow"
-            ) from None
+            )
 
         self.flow = app.flows[0]
         self.setup_queues(self.flow)
@@ -95,11 +99,21 @@ class RequestResponseFlowController:
         flow.set_next_component(rrcComponent)
 
     def do_broker_request_response(
-        self, request_message, stream=False, streaming_complete_expression=None
+        self,
+        request_message,
+        stream=False,
+        streaming_complete_expression=None,
+        wait_for_response: bool = True,
     ):
+        if self._is_shutdown.is_set():
+            raise SessionClosedError("Request/response session has been closed.")
+
         # Send the message to the broker
         self.send_message(request_message, stream, streaming_complete_expression)
 
+        if not wait_for_response:
+            return
+
         # Now we will wait for the response
         now = time.time()
         elapsed_time = now - self.enqueue_time
@@ -109,6 +123,8 @@ class RequestResponseFlowController:
             # until we receive the last message. Use the expression to determine
             # if this is the last message
             while True:
+                if self._is_shutdown.is_set():
+                    raise SessionClosedError("Request/response session has been closed.")
                 try:
                     # Calculate remaining time based on the most recent enqueue_time
                     now = time.time()
@@ -116,6 +132,10 @@ class RequestResponseFlowController:
                     remaining_timeout = max(0, self.request_expiry_s - elapsed_time)
 
                     event = self.response_queue.get(timeout=remaining_timeout)
+                    if event is None:  # Check for shutdown signal
+                        raise SessionClosedError(
+                            "Request/response session has been closed while waiting for a streaming response."
+                        )
                     if event.event_type == EventType.MESSAGE:
                         self.enqueue_time = time.time()
                         message = event.data
@@ -125,31 +145,35 @@ class RequestResponseFlowController:
                             return
                 except queue.Empty:
                     if (time.time() - self.enqueue_time) > self.request_expiry_s:
-                        raise TimeoutError(  # pylint: disable=raise-missing-from
-                            "Timeout waiting for response"
+                        raise TimeoutError(
+                            f"Response not received within the timeout period of {self.request_expiry_ms} ms"
                         ) from None
-                except Exception:
+                except Exception as e:
                     raise ValueError(
                         "Error while waiting for response from broker request-response flow"
-                    ) from None
+                    ) from e
 
         # If we are not in streaming mode, we will return a single message
         # and then stop the iterator
         try:
             event = self.response_queue.get(timeout=remaining_timeout)
+            if event is None:  # Check for shutdown signal
+                raise SessionClosedError(
+                    "Request/response session has been closed while waiting for a response."
+                )
             if event.event_type == EventType.MESSAGE:
                 message = event.data
                 yield message, True
                 return
         except queue.Empty:
             if (time.time() - self.enqueue_time) > self.request_expiry_s:
-                raise TimeoutError(  # pylint: disable=raise-missing-from
-                    "Timeout waiting for response"
+                raise TimeoutError(
+                    f"Response not received within the timeout period of {self.request_expiry_ms} ms"
                 ) from None
-        except Exception:
+        except Exception as e:
             raise ValueError(
                 "Error while waiting for response from broker request-response flow"
-            ) from None
+            ) from e
 
     def send_message(
         self, message: Message, stream=False, streaming_complete_expression=None
@@ -158,7 +182,7 @@ class RequestResponseFlowController:
         if not self.input_queue:
             raise ValueError(
                 f"Input queue for flow {self.flow.name} not found"
-            ) from None
+            )
 
         # Need to set the previous object to the required input for the
         # broker_request_response component
@@ -179,3 +203,22 @@ class RequestResponseFlowController:
 
     def enqueue_response(self, event):
         self.response_queue.put(event)
+
+    def cleanup(self):
+        """
+        Cleans up the resources used by the controller, including its internal flow.
+        This will cause any waiting callers to fail with SessionClosedError.
+        """
+        if self._is_shutdown.is_set():
+            return
+        log.debug("Cleaning up RequestResponseFlowController.")
+        self._is_shutdown.set()
+
+        # Unblock any thread waiting on the response queue
+        try:
+            self.response_queue.put_nowait(None)
+        except queue.Full:
+            pass  # Queue is full, consumer will eventually get to None
+
+        if self.flow:
+            self.flow.cleanup()
