@@ -1,3 +1,4 @@
+import logging
 import time
 import pickle
 import threading
@@ -7,7 +8,8 @@ from threading import Lock
 from sqlalchemy import create_engine, Column, String, Float, LargeBinary
 from sqlalchemy.orm import declarative_base, sessionmaker
 from ..common.event import Event, EventType
-from ..common.log import log
+
+log = logging.getLogger(__name__)
 
 
 class CacheStorageBackend(ABC):
@@ -322,8 +324,8 @@ def create_storage_backend(backend_type: str = None, **kwargs) -> CacheStorageBa
         if not connection_string:
             raise ValueError(
                 "SQLAlchemy backend requires a connection_string"
-            ) from None
+            )
         return SQLAlchemyStorage(connection_string)
     # Add more backend types here as needed
-    raise ValueError(f"Unsupported storage backend: {backend_type}") from None
+    raise ValueError(f"Unsupported storage backend: {backend_type}")
 
