@@ -1,16 +1,17 @@
 """Entry point for the Solace AI Event Connector"""
 
+import logging
 import threading
 import queue
-import traceback
 import os
 import time
 import random
 
 from datetime import datetime
 from typing import List, Dict, Any
-from .common.log import log, setup_log
+from .common.log import setup_log
 from .common.utils import resolve_config_values, import_module
+from .common.exceptions import InitializationError
 from .flow.flow import Flow
 from .flow.app import App
 from .flow.timer_manager import TimerManager
@@ -18,6 +19,7 @@ from .common.event import Event, EventType
 from .services.cache_service import CacheService, create_storage_backend
 from .common.monitoring import Monitoring
 
+log = logging.getLogger(__name__)
 
 class SolaceAiConnector:
     """Solace AI Connector"""
@@ -61,11 +63,9 @@ class SolaceAiConnector:
             log.info("Solace AI Event Connector started successfully")
         except KeyboardInterrupt:
             log.info("Received keyboard interrupt - stopping")
-
-            raise KeyboardInterrupt from None
-        except Exception as e:
-            log.error("Error during Solace AI Event Connector startup", trace=e)
-            raise ValueError("An error occurred during startup") from None
+            raise KeyboardInterrupt
+        except Exception:
+            raise InitializationError("An error occurred during startup")
 
     def create_apps(self):
         """Create apps from the configuration"""
@@ -86,10 +86,9 @@ class SolaceAiConnector:
 
         except KeyboardInterrupt:
             log.info("Received keyboard interrupt - stopping")
-            raise KeyboardInterrupt from None
-        except Exception as e:
-            log.error("Error creating apps", trace=e)
-            raise ValueError("An error occurred during app creation") from None
+            raise
+        except Exception:
+            raise InitializationError("An error occurred during app creation")
             
     def _create_default_app(self):
         """Create a default app from top-level flows configuration"""
@@ -182,13 +181,13 @@ class SolaceAiConnector:
                 if found_class:
                     raise ValueError(
                         f"App module '{app_module}' contains multiple App subclasses. Specify class_name in info."
-                    ) from None
+                    )
                 found_class = obj
                 
         if not found_class:
             raise ValueError(
                 f"App module '{app_module}' does not contain an App subclass or define class_name in info."
-            ) from None
+            )
             
         log.debug(
             "Using App subclass %s found in module %s",
@@ -256,7 +255,7 @@ class SolaceAiConnector:
         # This should not be called directly anymore
         raise NotImplementedError(
             "create_flow is deprecated, use create_apps instead"
-        ) from None
+        )
 
     def send_message_to_flow(self, flow_name, message):
         """Send a message to a flow"""
@@ -306,7 +305,7 @@ class SolaceAiConnector:
                     break
             except KeyboardInterrupt:
                 log.info("Received keyboard interrupt - stopping")
-                raise KeyboardInterrupt from None
+                raise
 
     def cleanup(self):
         """Clean up resources and ensure all threads are properly joined"""
@@ -314,8 +313,8 @@ class SolaceAiConnector:
         for app in self.apps:
             try:
                 app.cleanup()
-            except Exception as e:
-                log.error("Error cleaning up app", trace=e)
+            except Exception:
+                log.exception("Error cleaning up app")
         self.apps.clear()
         self.flows.clear()  # Keep for backward compatibility refs?
 
@@ -324,8 +323,8 @@ class SolaceAiConnector:
             try:
                 while not q.empty():
                     q.get_nowait()
-            except Exception as e:
-                log.error(f"Error cleaning queue {queue_name}", trace=e)
+            except Exception:
+                log.exception(f"Error cleaning queue {queue_name}")
         self.flow_input_queues.clear()
 
         if hasattr(self, "trace_queue") and self.trace_queue:
@@ -351,7 +350,7 @@ class SolaceAiConnector:
         log_file_level = log_config.get("log_file_level", "INFO")
         log_file = log_config.get("log_file", "solace_ai_connector.log")
         log_format = log_config.get("log_format", "pipe-delimited")
-        enable_trace = log_config.get("enable_trace", True)
+        enable_trace = log_config.get("enable_trace", False)
 
         # Get logback values
         logback = log_config.get("logback", {})
@@ -404,17 +403,17 @@ class SolaceAiConnector:
                         if self.stop_signal.is_set():
                             break
                         continue
-        except Exception as e:
-            log.error("Error in trace handler thread", trace=e)
+        except Exception:
+            log.exception("Error in trace handler thread")
 
     def validate_config(self):
         """Validate the configuration structure."""
         if not self.config:
-            raise ValueError("No config provided") from None
+            raise ValueError("No config provided")
 
         # Check if either apps or flows are defined at the top level
         if not self.config.get("apps") and not self.config.get("flows"):
-            raise ValueError("No apps or flows defined in configuration file") from None
+            raise ValueError("No apps or flows defined in configuration file")
 
         if not self.config.get("log"):
             log.warning("No log config provided - using defaults")
@@ -422,18 +421,18 @@ class SolaceAiConnector:
         # Validate apps if defined
         if self.config.get("apps"):
             if not isinstance(self.config.get("apps"), list):
-                raise ValueError("'apps' must be a list") from None
+                raise ValueError("'apps' must be a list")
 
             for index, app in enumerate(self.config.get("apps", [])):
                 if not isinstance(app, dict):
                     raise ValueError(
                         f"App definition at index {index} must be a dictionary"
-                    ) from None
+                    )
 
                 if not app.get("name"):
                     raise ValueError(
                         f"App name not provided in app definition at index {index}"
-                    ) from None
+                    )
                 app_name = app.get("name")
 
                 # --- Modified Validation Logic ---
@@ -454,7 +453,7 @@ class SolaceAiConnector:
                     if not has_flows and not (has_broker and has_components):
                         raise ValueError(
                             f"App '{app_name}' must define either 'flows' or both 'broker' and 'components'"
-                        ) from None
+                        )
                     if has_flows and (has_broker or has_components):
                         log.warning(
                             "App '%s' defines both 'flows' and 'broker'/'components'. "
@@ -472,7 +471,7 @@ class SolaceAiConnector:
                         if not isinstance(broker_config, dict):
                             raise ValueError(
                                 f"App '{app_name}' has invalid 'broker' section (must be a dictionary)"
-                            ) from None
+                            )
                         required_broker_keys = [
                             "broker_url",
                             "broker_username",
@@ -483,41 +482,41 @@ class SolaceAiConnector:
                             if not broker_config.get(key):
                                 raise ValueError(
                                     f"App '{app_name}' broker config missing required key: '{key}'"
-                                ) from None
+                                )
                         if broker_config.get("input_enabled") and not broker_config.get(
                             "queue_name"
                         ):
                             raise ValueError(
                                 f"App '{app_name}' broker config missing 'queue_name' when 'input_enabled' is true"
-                            ) from None
+                            )
 
                         # Validate components is a list
                         if not isinstance(components_config, list):
                             raise ValueError(
                                 f"App '{app_name}' has invalid 'components' section (must be a list)"
-                            ) from None
+                            )
                         if not components_config:
                             raise ValueError(
                                 f"App '{app_name}' must have at least one component defined in 'components'"
-                            ) from None
+                            )
 
                         # Validate each component entry
                         for comp_index, component in enumerate(components_config):
                             if not isinstance(component, dict):
                                 raise ValueError(
                                     f"App '{app_name}' component definition at index {comp_index} must be a dictionary"
-                                ) from None
+                                )
                             if not component.get("name"):
                                 raise ValueError(
                                     f"App '{app_name}' component at index {comp_index} missing 'name'"
-                                ) from None
+                                )
                             comp_name = component.get("name")
                             if not component.get(
                                 "component_module"
                             ) and not component.get("component_class"):
                                 raise ValueError(
                                     f"App '{app_name}' component '{comp_name}' missing 'component_module' or 'component_class'"
-                                ) from None
+                                )
 
                             # Validate subscriptions if input is enabled
                             if broker_config.get("input_enabled"):
@@ -531,17 +530,17 @@ class SolaceAiConnector:
                                 elif not isinstance(subscriptions, list):
                                     raise ValueError(
                                         f"App '{app_name}' component '{comp_name}' has invalid 'subscriptions' (must be a list)"
-                                    ) from None
+                                    )
                                 else:
                                     for sub_index, sub in enumerate(subscriptions):
                                         if not isinstance(sub, dict):
                                             raise ValueError(
                                                 f"App '{app_name}' component '{comp_name}' subscription at index {sub_index} must be a dictionary"
-                                            ) from None
+                                            )
                                         if not sub.get("topic"):
                                             raise ValueError(
                                                 f"App '{app_name}' component '{comp_name}' subscription at index {sub_index} missing 'topic'"
-                                            ) from None
+                                            )
 
                     # Standard Mode Validation (only if structure implies standard)
                     elif has_flows:
@@ -552,7 +551,7 @@ class SolaceAiConnector:
         # Validate top-level flows (for backward compatibility)
         if self.config.get("flows"):
             if not isinstance(self.config.get("flows"), list):
-                raise ValueError("'flows' at the top level must be a list") from None
+                raise ValueError("'flows' at the top level must be a list")
             if not self.config.get(
                 "apps"
             ):  # Only validate top-level if no apps are defined
@@ -568,44 +567,44 @@ class SolaceAiConnector:
     def _validate_flows(self, flows, context):
         """Validate flows configuration (helper method)."""
         if not isinstance(flows, list):
-            raise ValueError(f"Flows definition in {context} must be a list") from None
+            raise ValueError(f"Flows definition in {context} must be a list")
 
         for index, flow in enumerate(flows):
             if not isinstance(flow, dict):
                 raise ValueError(
                     f"Flow definition at index {index} in {context} must be a dictionary"
-                ) from None
+                )
             if not flow.get("name"):
                 raise ValueError(
                     f"Flow name not provided in flow {index} of {context}"
-                ) from None
+                )
             flow_name = flow.get("name")
 
             if "components" not in flow:  # Check presence of the key
                 raise ValueError(
                     f"Flow components list not provided in flow '{flow_name}' of {context}"
-                ) from None
+                )
 
             # Verify that the components list is a list
             if not isinstance(flow.get("components"), list):
                 raise ValueError(
                     f"Flow components is not a list in flow '{flow_name}' of {context}"
-                ) from None
+                )
             if not flow.get("components"):  # Check if list is empty
                 raise ValueError(
                     f"Flow '{flow_name}' in {context} must have at least one component"
-                ) from None
+                )
 
             # Loop through the components and validate them
             for component_index, component in enumerate(flow.get("components", [])):
                 if not isinstance(component, dict):
                     raise ValueError(
                         f"Component definition at index {component_index} in flow '{flow_name}' of {context} must be a dictionary"
-                    ) from None
+                    )
                 if not component.get("component_name"):
                     raise ValueError(
                         f"component_name not provided in flow '{flow_name}', component {component_index} of {context}"
-                    ) from None
+                    )
                 comp_name = component.get("component_name")
 
                 # In standard flows, component_module or component_class is required
@@ -614,7 +613,7 @@ class SolaceAiConnector:
                 ):
                     raise ValueError(
                         f"Either 'component_module' or 'component_class' must be provided for component '{comp_name}' in flow '{flow_name}' of {context}"
-                    ) from None
+                    )
 
     def get_flows(self):
         """Return the flows"""
