@@ -1,8 +1,11 @@
 """Append Transform - add a value to a list"""
 
-from ..common.log import log
+import logging
+
 from .transform_base import TransformBase
 
+log = logging.getLogger(__name__)
+
 info = {
     "class_name": "AppendTransform",
     "description": ("Select a source value and append it to a destination list. "),
