@@ -44,7 +44,7 @@ class TransformBase:
             if not allow_none:
                 raise ValueError(
                     f"{self.log_identifier}: Transform does not have a source expression"
-                ) from None
+                )
             else:
                 return None
         return source_expression
@@ -54,5 +54,5 @@ class TransformBase:
         if not dest_expression:
             raise ValueError(
                 f"{self.log_identifier}: Transform does not have a dest expression"
-            ) from None
+            )
         return dest_expression
