@@ -4,6 +4,8 @@ import sys
 import pytest
 import yaml
 
+from solace_ai_connector.common.exceptions import InitializationError
+
 sys.path.append("src")
 
 from solace_ai_connector.test_utils.utils_for_test_files import (  # pylint: disable=wrong-import-position
@@ -21,9 +23,6 @@ from solace_ai_connector.solace_ai_connector import (  # pylint: disable=wrong-i
 from solace_ai_connector.common.message import Message
 import solace_ai_connector.components.general.pass_through
 
-# from solace_ai_connector.common.log import log
-
-
 def test_no_config_file():
     """Test that the program exits if no configuration file is provided"""
     try:
@@ -239,7 +238,7 @@ apps:
           - component_name: delay1
             component_module: utils
 """
-    with pytest.raises(ValueError) as e:
+    with pytest.raises(InitializationError) as e:
         create_connector(
             config_yaml,
         )
